@@ -8,10 +8,10 @@ Created on 14/07/2020 下午11:48
 # todo: convert the config file to bash format.
 db_config = {
     'db_path': 'data',
-    'ontology_file': f'{data_path}/to.wto.ro.funRiceGene.obo',
+    'ontology_file': f'data/to.wto.ro.funRiceGene.obo',
     'ontology_url': 'https://raw.githubusercontent.com/YaoXinZhi/Plant-Trait-Enrichment/master/data/to-basic.obo',
     # 'PT_anno_file': '../data/Oryzasebase.txt',
-    'PT_anno_file': f'{data_path}/Total_Association.txt',
+    'PT_anno_file': f'data/Total_Association.txt',
     'PT_anno_url': 'https://raw.githubusercontent.com/YaoXinZhi/Plant-Trait-Enrichment/master/data/Oryzasebase.txt',
 
     'evidence_file': '',
